#
# FILTER TEXT FILES
#
# Gets rid of funky characters (x96, x97, x98, x99) that sometimes
# get put into files scraped from web page or extracted from a PDF.
# 
# These funky characters cause problems for the tm_map() operations.
# 
#
# This program takes all the text files found in the source directory
# and replaces those characters with a '-' character.  It then writes the
# filtered data out to the target directory.
# 
# April 20/13 by bcg
#   - added filtering of xe9 and xe8 (replace with "e")
#   - replaced "\" with "\\" so things would work under Linux
# April 12/13 by bcg
#   - added filtering of x93,x94 (replaced with " symbol)
#
# April 11/13 by bcg
#   - first cut
# 

#library(stringr)

# set working and data directories
setwd("/home/analyzeBudgetSpeeches")

# force the local to be common amoung any and all machines
Sys.setlocale('LC_ALL','C')

# define the dataset to be used, and where to put filtered data
//dataSet <- "Ontario_Raw"
//dataTarget <- "Ontario"
dataSet <- "Federal0"
dataTarget <- "Federal"

dataDir <- paste(getwd(),"/", dataSet,sep="")
targetDir <- paste(getwd(),"/", dataTarget,sep="")

# get list of all the files in the source directory
fileList <- list.files(dataDir)

# process each file in the source directory
for (fileName in fileList)
{
  fullName <- paste(dataDir,"/", fileName, sep="")
  
  print(paste("Working on ", fullName))
  
  # load the text from the file
  fileIn <- file(fullName)
  inData <- readLines(fileIn)
  close(fileIn)
  
  # using scan() creates a vector of words (ie. destroys original structure)
  #  inData <- scan(fullName, what="character")
    
  # show if there any of the extra characters
  print(length(grep('\\xe8', inData)))
  print(length(grep('\\xe9', inData)))
  print(length(grep('\\x93', inData)))
  print(length(grep('\\x94', inData)))
  print(length(grep('\\x96', inData)))
  print(length(grep('\\x97', inData)))
  print(length(grep('\\x98', inData)))
  print(length(grep('\\x99', inData)))
  
  # if there are any funky characters to deal with
  if (   (length(grep('\\x96', inData)) > 0) ||
         (length(grep('\\xe8', inData)) > 0) ||
         (length(grep('\\xe9', inData)) > 0) ||
         (length(grep('\\x93', inData)) > 0) ||
         (length(grep('\\x94', inData)) > 0) ||
         (length(grep('\\x97', inData)) > 0) ||
         (length(grep('\\x98', inData)) > 0) ||
         (length(grep('\\x99', inData)) > 0) )
  {
    # replace 'em
    filteredData <- sub('\\x96', '-', inData)
    filteredData <- sub('\\x97', '-', filteredData)
    filteredData <- sub('\\x98', '-', filteredData)
    filteredData <- sub('\\x99', '-', filteredData)
    filteredData <- sub('\\x99', '-', filteredData)
    filteredData <- sub('\\x93', '"', filteredData)
    filteredData <- sub('\\x94', '"', filteredData)
    filteredData <- sub('\\xe8', 'e', filteredData)
    filteredData <- sub('\\xe9', 'e', filteredData)
    
    # see if there any of the extra characters left after filtering
    # grep('\x96', filteredData)
    # grep('\x97', filteredData)
    # grep('\x98', filteredData)
    # grep('\x99', filteredData)
    
    # write the filtered data to the target directory
    targetName <- paste(targetDir,"/", fileName, sep="")
    fileOut <- file(targetName, encoding = "UTF-8")
    writeLines(filteredData, fileOut)
    close(fileOut)
    
    outStr <- paste("   ", fileOut)
    print(outStr)
  }
  else
  {
    print("   nothing to filter")
    
    # write the original data to the target directory
    targetName <- paste(targetDir,"/", fileName, sep="")
    fileOut <- file(targetName)
    writeLines(inData, fileOut)
    close(fileOut)
    
    outStr <- paste("   ", fileOut)
    print(outStr)
  }
  
}     # =====  end of for()




